This directory contains examples that demonstrate how to embed Bokeh plots and widgets as
DOM elements of larger documents. Typically, this is accomplished using the [`bokeh.embed`](https://bokeh.pydata.org/en/latest/docs/user_guide/embed.html) interface.
